@@ -38,7 +38,6 @@ NULL
 
 
 #' @keywords internal
-
 abbreviate_names <- function(x, minlength) {
   x$Variable <- abbreviate(x$Variable, minlength = minlength)
   x
@@ -46,12 +45,7 @@ abbreviate_names <- function(x, minlength) {
 
 
 #' @keywords internal
-sort_importance_scores <- function(x, decreasing) {
-  x[order(x$Importance, decreasing = decreasing), ]
-}
-
-#' @keywords internal
-check_FUN <- function(x) {
+check_var_fun <- function(x) {
   # x should be a named list of two functions with names "con" and "cat"
   if (!is.list(x)) {
     stop("FUN should be a list.", call. = FALSE)
@@ -67,3 +61,19 @@ check_FUN <- function(x) {
     stop("FUN should be a list of two functions.", call. = FALSE)
   }
 }
+
+
+#' @keywords internal
+permute_columns <- function(x, columns = NULL) {
+  if (is.null(columns)) {
+    stop("No columns specified for permutation.")
+  }
+  x[, columns] <- x[sample(nrow(x)), columns]
+  x
+}
+
+
+#' @keywords internal
+sort_importance_scores <- function(x, decreasing) {
+  x[order(x$Importance, decreasing = decreasing), ]
+}
